pub struct BotManifest {
pub v: u32,
pub commands: Vec<CommandSpec>,
}Expand description
The bot’s full published interface. Unknown fields are ignored on read
(forward compatibility); v gates breaking schema changes.
Fields
v: u32commands: Vec<CommandSpec>Implementations
Sourceimpl BotManifest
impl BotManifest
Sourcepub fn validate(&self) -> Result<(), String>
pub fn validate(&self) -> Result<(), String>
Fail-closed structural validation, applied to our own manifests before publish AND to fetched foreign ones before use.
Sourcepub fn command(&self, name: &str) -> Option<&CommandSpec>
pub fn command(&self, name: &str) -> Option<&CommandSpec>
Look up a command by name.
Sourcepub fn from_event(event: &Event) -> Result<Self, String>
pub fn from_event(event: &Event) -> Result<Self, String>
Parse + validate a manifest from an event’s content. The event must be the manifest kind and is otherwise treated as untrusted input.