Database schema and migrations.
Constants
- HIGHEST_
MIGRATION_ ID - Highest migration id this build knows how to apply.
- SQL_
SCHEMA
Functions
- applied_
migration_ high_ water - Highest migration id recorded in this DB; 0 for a fresh or pre-tracking one.
- mark_
migration_ applied - Mark a migration as applied (within a transaction)
- migration_
applied - Check if a specific migration has already been applied
- run_
migrations - Run database migrations for schema updates