pub fn set_nip55_state(new_state: Nip55State)Expand description
Install a new state and fan out a nip55_state event. No-op if unchanged,
so per-op confirmation of an already-known state doesn’t spam the UI.
pub fn set_nip55_state(new_state: Nip55State)Install a new state and fan out a nip55_state event. No-op if unchanged,
so per-op confirmation of an already-known state doesn’t spam the UI.