pub async fn subscription_id() -> Option<SubscriptionId>Expand description
The subscription id of the live Community subscription, if any. Lets a notification loop test whether an arriving event belongs to the Community sub.
pub async fn subscription_id() -> Option<SubscriptionId>The subscription id of the live Community subscription, if any. Lets a notification loop test whether an arriving event belongs to the Community sub.