Module schema

Module schema 

Database schema and migrations.

Constants

HIGHEST_MIGRATION_ID
Highest migration id this build knows how to apply.
SQL_SCHEMA

Functions

applied_migration_high_water
Highest migration id recorded in this DB; 0 for a fresh or pre-tracking one.
mark_migration_applied
Mark a migration as applied (within a transaction)
migration_applied
Check if a specific migration has already been applied
run_migrations
Run database migrations for schema updates