pub fn set_nostr_client(client: Client)
Install the Nostr client for the current session. Replaces any prior client without shutting it down — reset_session() is responsible for orderly teardown of the outgoing client.
reset_session()